/*
 *  Copyright (C) 2000 Marco Pesenti Gritti
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

void mozilla_prefs_set (void);
void mozilla_prefs_set_default_charset (void);
void mozilla_prefs_set_languages (void);
void mozilla_prefs_set_fonts_defaults (void);
//void mozilla_prefs_set_fonts (LanguageFontInfo *info, int lang_enc);
int mozilla_prefs_set_font (gchar *name, gchar *key, int lang_enc);

void mozilla_prefs_get_fonts (LanguageFontInfo *info, int lang_enc);
void mozilla_prefs_set_user_agent (void);
void mozilla_prefs_set_font_size (gchar *key, int size, int lang_enc);

void mozilla_prefs_set_proxy (void);
